@@ -17,7 +17,7 @@
 offset = 0
 while line = gets
   unless line =~ /^;/
-    print [offset].pack "N"
+    print [offset].pack("N")
   end
   offset += line.length
 end
